==> haskell-hls-explicit-imports-plugin-2.0.0.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.0.0.0-94QNrpVQahgDKjcZGYqtzg
key:                  hls-explicit-imports-plugin-2.0.0.0-94QNrpVQahgDKjcZGYqtzg
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  0f8a439559b8fab161ea0ba885d5ec8b
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-2.0.0.0-94QNrpVQahgDKjcZGYqtzg

depends:
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-6hTfaheG6VuKuwRJZ4Llqv
    hls-graph-2.0.0.0-BxxBQbIObzl64Ex9I7AC7s
    hls-plugin-api-2.0.0.0-KVOtPzuMQs9GkM38tQXN9J
    lsp-1.6.0.0-CSMkkjouyWs2BiL8kksf63 text-2.0.2
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-imports-plugin-2.0.0.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.0.0.0-LY2vkkv8530mizSqGodGl
key:                  hls-explicit-imports-plugin-2.0.0.0-LY2vkkv8530mizSqGodGl
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f1e5023153ec967fc2721f15f98402b9
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:         HShls-explicit-imports-plugin-2.0.0.0-LY2vkkv8530mizSqGodGl
depends:
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-IQHZ41Bdb1tG2CG2PmBgb5
    hls-graph-2.0.0.0-6KKO3bc46thA1WiJCuzYg2
    hls-plugin-api-2.0.0.0-HXuoqsWA2vn6nZ63Ot0sEJ
    lsp-1.6.0.0-7IaudNMUb3vDN01orV4Wg0 text-2.0.2
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
